-- Author: Lionel Leeser
-- Date: 13.10.20
-- Notes: tileset from OpenGameArt.org from somebody who asked to be credited as "Gravity Games Interactive", so here you are.

-- The goal is to make work Sti with Luven.
-- How to align everything together ?

Luven = require "libs/luven/luven"
Sti = require "libs/sti"
Bump = require "libs/bump"

G_TILESIZE = 8
G_ZOOM = 2.5
G_VIRTUAL_WIDTH = love.graphics:getWidth() / G_ZOOM
G_VIRTUAL_HEIGHT = love.graphics:getHeight() / G_ZOOM

local min_dt = 0
local next_time = 0

function love.load()
    min_dt = 1/60 -- 60 fps

    Luven.init()

    G_WORLD = Bump.newWorld(G_TILE_SIZE)

    Luven.setAmbientLightColor({0.4, 0.4, 0.4})

    Luven.camera:init(0, 0)
    Luven.camera:setScale(G_ZOOM)

    G_MAP = Sti("assets/tilemaps/tilemap.lua", { "bump" })
    G_MAP:bump_init(G_WORLD)
end

function love.update(dt)
    next_time = next_time + min_dt

    Luven.update(dt)
    G_MAP:update(dt)
end

function love.draw()
	love.graphics.setBackgroundColor(0, 0, 0, 1)

	Luven.drawBegin()
		-- G_MAP:draw(Luven.camera.x + G_VIRTUAL_WIDTH / 2, Luven.camera.y + G_VIRTUAL_HEIGHT / 2, Luven.camera.scaleX, Luven.camera.scaleY)
		G_MAP:draw(-Luven.camera.x, -Luven.camera.y, Luven.camera.scaleX, Luven.camera.scaleY)
	Luven.drawEnd()

	Luven.camera:set()
		G_MAP:bump_draw(-Luven.camera.x, -Luven.camera.y, Luven.camera.scaleX, Luven.camera.scaleY)
	Luven.camera:unset()

    local cur_time = love.timer.getTime()
    if next_time <= cur_time then
        next_time = cur_time
        return
    end
    love.timer.sleep(next_time - cur_time)
end

function love.keypressed(key)
    if (key == "up") then
    	Luven.camera:move(0, -G_TILESIZE)
    elseif (key == "left") then
    	Luven.camera:move(-G_TILESIZE, 0)
    elseif (key == "right") then
    	Luven.camera:move(G_TILESIZE, 0)
    elseif (key == "down") then
    	Luven.camera:move(0, G_TILESIZE)
    end
end